@@ -3,7 +3,7 @@
  *
  * Setup of an alert function.
  *
- * Copyright (c) 2009-2018, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+ * Copyright (c) 2009-2019, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
  */
 
 -- Adjust this setting to control where the objects get created.
@@ -25,7 +25,7 @@ CREATE TABLE statsrepo.alert
 	response_avg			bigint	NOT NULL DEFAULT 10      CHECK (response_avg >= -1),
 	response_worst			bigint	NOT NULL DEFAULT 60      CHECK (response_worst >= -1),
 	backend_max				integer	NOT NULL DEFAULT 100     CHECK (backend_max >= -1),
-	fragment_percent		integer	NOT NULL DEFAULT 70      CHECK (fragment_percent >= -1 AND fragment_percent <= 100),
+	correlation_percent		integer	NOT NULL DEFAULT 70      CHECK (correlation_percent >= -1 AND correlation_percent <= 100),
 	disk_remain_percent		integer	NOT NULL DEFAULT 20      CHECK (disk_remain_percent >= -1 AND disk_remain_percent <= 100),
 	loadavg_1min			real	NOT NULL DEFAULT 7.0     CHECK (loadavg_1min = -1 OR loadavg_1min >= 0),
 	loadavg_5min			real	NOT NULL DEFAULT 6.0     CHECK (loadavg_5min = -1 OR loadavg_5min >= 0),
@@ -77,9 +77,9 @@ BEGIN
 		statsrepo.div((c.rollbacks - p.rollbacks), duration_in_sec),
 		statsrepo.div((c.commits - p.commits), duration_in_sec)
 	INTO val_rollback, val_commit
-	FROM (SELECT sum(xact_rollback) AS rollbacks, sum(xact_commit) AS commits
+	FROM (SELECT pg_catalog.sum(xact_rollback) AS rollbacks, pg_catalog.sum(xact_commit) AS commits
 			FROM statsrepo.database WHERE snapid = $1.snapid) AS c,
-		 (SELECT sum(xact_rollback) AS rollbacks, sum(xact_commit) AS commits
+		 (SELECT pg_catalog.sum(xact_rollback) AS rollbacks, pg_catalog.sum(xact_commit) AS commits
 			FROM statsrepo.database WHERE snapid = $2.snapid) AS p;
 
 	-- alert if rollbacks/sec is higher than threshold.
@@ -114,7 +114,7 @@ DECLARE
 BEGIN
 	-- calculate the garbage size.
 	SELECT
-		statsrepo.div(sum(c.garbage_size), 1024 * 1024)
+		statsrepo.div(pg_catalog.sum(c.garbage_size), 1024 * 1024)
 	INTO val_gb_size
 	FROM
 		(SELECT
@@ -123,7 +123,7 @@ BEGIN
 
 	-- calculate the garbage ratio.
 	SELECT
-		statsrepo.div((100 * sum(c.garbage_size)), sum(c.size))
+		statsrepo.div((100 * pg_catalog.sum(c.garbage_size)), pg_catalog.sum(c.size))
 	INTO val_gb_pct
 	FROM
 		(SELECT
@@ -176,8 +176,8 @@ DECLARE
 BEGIN
 	-- calculate the average and maximum of the query-response-time.
 	SELECT
-		avg((c.total_time - coalesce(p.total_time, 0)) / (c.calls - coalesce(p.calls, 0))),
-		max((c.total_time - coalesce(p.total_time, 0)) / (c.calls - coalesce(p.calls, 0)))
+		pg_catalog.avg((c.total_time - coalesce(p.total_time, 0)) / (c.calls - coalesce(p.calls, 0))),
+		pg_catalog.max((c.total_time - coalesce(p.total_time, 0)) / (c.calls - coalesce(p.calls, 0)))
 	INTO val_res_avg, val_res_max
 	FROM (SELECT dbid, userid, total_time, calls, query
 			FROM statsrepo.statement WHERE snapid = $1.snapid) AS c
@@ -226,21 +226,21 @@ END;
 $$
 LANGUAGE plpgsql;
 
--- alert function for check the fragmentation of table
-CREATE FUNCTION statsrepo.alert_fragment(
+-- alert function for check the correlation of table
+CREATE FUNCTION statsrepo.alert_correlation(
 	statsrepo.snapshot,
 	statsrepo.alert
 ) RETURNS SETOF text AS
 $$
 DECLARE
-	val_fragment_table  text;
-	val_fragment_pct    float8;
+	val_table            text;
+	val_correlation_pct  float8;
 BEGIN
-	-- alert if fragment ratio of the clustered index data table is higher than threshold.
-	FOR val_fragment_table, val_fragment_pct IN
+	-- alert if correlation ratio of the clustered index data table is higher than threshold.
+	FOR val_table, val_correlation_pct IN
 		SELECT
 			i.database || '.' || i.schema || '.' || i.table,
-			(100 * abs(c.correlation))::numeric(5,2)
+			(100 * pg_catalog.abs(c.correlation))::numeric(5,2)
 		FROM
 			statsrepo.indexes i,
 			statsrepo.column c
@@ -252,10 +252,10 @@ BEGIN
 			AND c.correlation IS NOT NULL
 			AND c.snapid = $1.snapid
 	LOOP
-		IF $2.fragment_percent >= 0 AND val_fragment_pct < $2.fragment_percent THEN
+		IF $2.correlation_percent >= 0 AND val_correlation_pct < $2.correlation_percent THEN
 			RETURN NEXT 'correlation of the clustered table fell below threshold in snapshot ''' ||
-				$1.time::timestamp(0) || ''' --- ''' || val_fragment_table || ''', ' ||
-				val_fragment_pct || ' % (threshold = ' || $2.fragment_percent || ' %)';
+				$1.time::timestamp(0) || ''' --- ''' || val_table || ''', ' ||
+				val_correlation_pct || ' % (threshold = ' || $2.correlation_percent || ' %)';
 		END IF;
 	END LOOP;
 END;
@@ -330,19 +330,19 @@ BEGIN
 	-- alert if replication-delay(flush or replay) is higher than threshold.
 	FOR val_client, val_flush_delay, val_replay_delay IN
 		SELECT
-			host(r.client_addr) || ':' || r.client_port,
+			pg_catalog.host(r.client_addr) || ':' || r.client_port,
 			statsrepo.div(
 				statsrepo.xlog_location_diff(
-					split_part(r.current_location, ' ', 1),
-					split_part(r.flush_location, ' ', 1),
+					pg_catalog.split_part(r.current_location, ' ', 1),
+					pg_catalog.split_part(r.flush_location, ' ', 1),
 					i.xlog_file_size
 				),
 				1024 * 1024
 			),
 			statsrepo.div(
 				statsrepo.xlog_location_diff(
-					split_part(r.current_location, ' ', 1),
-					split_part(r.replay_location, ' ', 1),
+					pg_catalog.split_part(r.current_location, ' ', 1),
+					pg_catalog.split_part(r.replay_location, ' ', 1),
 					i.xlog_file_size
 				),
 				1024 * 1024
@@ -427,8 +427,8 @@ BEGIN
 		RETURN NEXT message;
 	END LOOP;
 
-	-- check the fragmentation of tables
-	FOR message IN SELECT * FROM statsrepo.alert_fragment(curr, setting)
+	-- check the correlation of tables
+	FOR message IN SELECT * FROM statsrepo.alert_correlation(curr, setting)
 	LOOP
 		RETURN NEXT message;
 	END LOOP;
